==> bootstrap-7.0.2.tgz: package/tsDist/components/dashboard/shared/SessionList/SessionList.js <==
import React from 'react';
import { Table, TableHeader, TableRow } from 'components/elements/Table/Table';
import { SessionListHeader } from './SessionListHeader';
import { SessionItem } from './SessionItem';
import { SessionListLoader } from './SessionListLoader';
import { TableWrapper, THeaderCellSmall, ErrorWrapper, SessionListContainer, } from './styles';
var SESSION_COUNT = 7;
export var SessionList = function (_a) {
    var listData = _a.listData;
    var sessions = listData.sessions, loading = listData.loading, error = listData.error;
    if (error) {
        return (React.createElement(React.Fragment, null,
            React.createElement(SessionListHeader, { listData: listData }),
            React.createElement(ErrorWrapper, null,
                React.createElement("p", null, "Error occurred while loading sessions. Please try again later"))));
    }
    var shouldDisplayLoader = loading || typeof sessions === 'undefined';
    return (React.createElement(SessionListContainer, null,
        React.createElement(SessionListHeader, { listData: listData }),
        shouldDisplayLoader ? (React.createElement(SessionListLoader, { count: SESSION_COUNT })) : (React.createElement(TableWrapper, null,
            React.createElement(Table, null,
                React.createElement(TableHeader, null,
                    React.createElement(TableRow, null,
                        React.createElement(THeaderCellSmall, null, "Name"),
                        React.createElement(THeaderCellSmall, null, "Progress"),
                        React.createElement(THeaderCellSmall, null, "Action"))),
                sessions.map(function (session) { return (React.createElement(SessionItem, { key: session.id, session: session })); }))))));
};

==> bootstrap-7.0.15.tgz: package/tsDist/components/dashboard/shared/SessionList/SessionList.js <==
import React from 'react';
import { Table, TableHeader, TableRow } from 'components/elements/Table/Table';
import { SessionListHeader } from './SessionListHeader';
import { SessionItem } from './SessionItem';
import { SessionListLoader } from './SessionListLoader';
import { TableWrapper, THeaderCellSmall, ErrorWrapper } from './styles';
var SESSION_COUNT = 7;
export var SessionList = function (_a) {
    var listData = _a.listData;
    var sessions = listData.sessions, loading = listData.loading, error = listData.error;
    if (error) {
        return (React.createElement(React.Fragment, null,
            React.createElement(SessionListHeader, { listData: listData }),
            React.createElement(ErrorWrapper, null,
                React.createElement("p", null, "Error occurred while loading sessions. Please try again later"))));
    }
    var shouldDisplayLoader = loading || typeof sessions === 'undefined';
    return (React.createElement(React.Fragment, null,
        React.createElement(SessionListHeader, { listData: listData }),
        shouldDisplayLoader ? (React.createElement(SessionListLoader, { count: SESSION_COUNT })) : (React.createElement(TableWrapper, null,
            React.createElement(Table, null,
                React.createElement(TableHeader, null,
                    React.createElement(TableRow, null,
                        React.createElement(THeaderCellSmall, null, "Name"),
                        React.createElement(THeaderCellSmall, null, "Progress"),
                        React.createElement(THeaderCellSmall, null, "Action"))),
                sessions.map(function (session) { return (React.createElement(SessionItem, { key: session.id, session: session })); }))))));
};
